@@ -14,6 +14,10 @@ format.tbl <- function(x, ..., n = NULL, width = NULL, n_extra = NULL) {
   format(trunc_mat(x, n = n, width = width, n_extra = n_extra))
 }
 
+#' @rdname formatting
+#' @export
+format.tbl_df <- format.tbl
+
 #' @rdname formatting
 #' @export
 print.tbl <- function(x, ..., n = NULL, width = NULL, n_extra = NULL) {
@@ -23,9 +27,7 @@ print.tbl <- function(x, ..., n = NULL, width = NULL, n_extra = NULL) {
 
 #' @rdname formatting
 #' @export
-print.tbl_df <- function(x, ..., n = NULL, width = NULL, n_extra = NULL) {
-  NextMethod()
-}
+print.tbl_df <- print.tbl
 
 #' @export
 `[[.tbl_df` <- function(x, i, j, ..., exact = TRUE) {
