@@ -83,6 +83,10 @@ test_that("trunc_mat output matches known output", {
     print(trunc_mat(tibble(`\n` = c("\n", '"')))),
     "trunc_mat/newline.txt")
 
+  expect_output_file_rel(
+    print(trunc_mat(tibble("mean(x)" = 5, "var(x)" = 3), width = 28)),
+    "trunc_mat/non-syntactic.txt")
+
   expect_output_knit(
     knitr::knit_print(trunc_mat(df_all, width = 60L)),
     "trunc_mat/all-knit-60.txt")
